@@ -1,7 +1,6 @@
 
 import os
 import binwalk
-from nose.tools import eq_, ok_
 
 def test_firmware_gzip():
     '''
@@ -17,13 +16,13 @@ def test_firmware_gzip():
                                quiet=True)
 
     # Test number of modules used
-    eq_(len(scan_result), 1)
+    assert len(scan_result) == 1
 
     # There should be only one result
-    eq_(len(scan_result[0].results), 1)
+    assert len(scan_result[0].results) == 1
 
     # That result should be at offset 0
-    eq_(scan_result[0].results[0].offset, 0)
+    assert scan_result[0].results[0].offset == 0
 
     # That result should be a gzip file
-    ok_(scan_result[0].results[0].description.startswith("gzip compressed data"))
+    assert scan_result[0].results[0].description.startswith("gzip compressed data")
